Decoder

Struct Decoder 

pub struct Decoder { /* private fields */ }
Decodes frames into requests and responses.

Implementations

Source

impl Decoder

pub fn new() -> Self

pub fn extend(&mut self, data: &[u8])

Appends data to the internal buffer.

pub fn extend_bytes(&mut self, data: Bytes)

Appends bytes to the internal buffer.

pub fn decode_frame(&mut self) -> Result<Option<Frame>, ProtocolError>

Attempts to decode the next frame from the buffer.

pub fn decode_request(&mut self) -> Result<Option<Request>, ProtocolError>

Attempts to decode the next request from the buffer.

pub fn decode_response(&mut self) -> Result<Option<Response>, ProtocolError>

Attempts to decode the next response from the buffer.

pub fn buffered(&self) -> usize

Returns the number of bytes currently buffered.

pub fn clear(&mut self)

Clears the internal buffer.